:mod:`oasis.stratification`.stratify_by_scores
===========================================================

.. currentmodule:: oasis.stratification

.. autofunction:: stratify_by_scores

.. Not needed since there is no "Examples" section in the docstrings
.. .. include:: oasis.stratification.stratify_by_scores.examples

.. raw:: html

    <div class="clearer"></div>